#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>

#include "glwidget.h"
#include "simulation.h"
#include "wg_parameters.h"
#include "wg_view.h"

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow();

protected:
    void keyPressEvent(QKeyEvent *event);

private slots:
    void open();
    void saveVtk();
    void initTimer();
    void run();
    void pause();
    void stop();
    void about();
    void update();
    void openColormap();
    void changeShader(int index);

private:
    void createActions();
    void createMenus();
    void createToolBars();
    void createStatusBar();
    void showStatusBarInfo();
    void createDockWidget();
    void createStatusBarInfo();
    void destroySimulation();
    void createShadersToolBar();

    void loadFile(QString &fileName);
    void loadColormap(QString &fileName);
    void setCurrentFile(const QString &fileName);
    QString strippedName(const QString &fullFileName);

    QString curFile;
    QMenu *fileMenu;
    QMenu *simulationMenu;
    QMenu *helpMenu;
    QToolBar *fileToolBar;
    QToolBar *simulationToolBar;
    QToolBar *viewToolBar;
    QAction *openAct;
    QAction *openColormapAct;
    QAction *saveVtkAct;
    QAction *exitAct;
    QAction *runAct;
    QAction *pauseAct;
    QAction *stopAct;
    QAction *aboutAct;
    GLWidget *glWidget;
    QTimer *timer;
	QDockWidget **dock;
	QLabel *mlupsLabel;
	QLabel *timeLabel;
	QLabel *fpsLabel;

	QToolBar *shadersToolBar;
	QLabel *shadersLabel;
    QComboBox *shadersComboBox;

    Simulation *sim;
    Input *input;
    Output *output;

	ParametersWidget *parameters;
	ViewWidget *view;
};

#endif
